resolve_tessdata_path

Function resolve_tessdata_path 

pub fn resolve_tessdata_path(
    app: &AppHandle,
    lang: &str,
) -> Result<String, String>
Resolve the tessdata directory path for the given language.

  • “eng” uses the bundled tessdata (or the Flatpak-provided path).
  • Other languages use the app data directory where traineddata files are downloaded on demand.